@@ -1,5 +1,4 @@
-from .__main__ import *
-__version__ = '2021.12.4.0.1'
+__version__ = '2021.12.5'
 
 def version():
     """Version Print"""
